@@ -39,14 +39,17 @@ class PasswordDialog : public QDialog
     Q_OBJECT
 
 public:
-    PasswordDialog(QStringList argv
+    PasswordDialog(const QString & cmd
+            , const QString & backendName
             , QWidget * parent = 0
             , Qt::WindowFlags f = 0);
     ~PasswordDialog();
 
-    virtual void showEvent(QShowEvent * event) override;
     QString password() const;
 
+protected:
+    virtual void showEvent(QShowEvent * event) override;
+
 private:
     QScopedPointer<Ui::PasswordDialog> ui;
     int mAttempt = 0;
